@@ -21,18 +21,19 @@
  */
 
 #ifndef LINT
-static char *const _cddbd_h_ident_ = "@(#)$Id: cddbd.h,v 1.39 2004/01/10 14:59:24 joerg78 Exp $";
+static char *const _cddbd_h_ident_ = "@(#)$Id: cddbd.h,v 1.43.2.1 2004/09/03 16:00:41 megari Exp $";
 #endif
 
 /* includes */
 #include <sys/types.h>
 #include <stdio.h>
 #include "list.h"
+#include "configurables.h"
 
 /* OS dependencies */
-#if defined __FreeBSD__ || defined __NetBSD__ || defined __sparc
+#if defined __FreeBSD__ || defined __NetBSD__ || defined __OpenBSD__ || (defined __SVR4 && defined __sun)
 #define HAS_UINT32_T
-#endif /* defined __FreeBSD__ || defined __NetBSD__ || defined __sparc */
+#endif /* defined __FreeBSD__ || defined __NetBSD__ || defined __OpenBSD__ || (defined __SVR4 && defined __sun) */
 
 #ifdef __linux__
 #include <stdint.h>
@@ -100,8 +101,8 @@ void bzero (void *b, size_t len);
 #define SPUT(c, buf) (buf)[cc] = c, cc++
 
 /* Fuzzy table header values. */
-#define FUZZY_MAGIC	0x32FD91C4
-#define FUZZY_VERSION	2
+#define FUZZY_MAGIC	    0x32FD91C5
+#define FUZZY_VERSION	3 
 
 /* Define empty (default) discid */
 #define DISCID_EMPTY	0x00000000
@@ -378,6 +379,14 @@ void bzero (void *b, size_t len);
 #define FL_REPAIR	2	/* DB checking level for repairing entries. */
 #define FL_REMOVE	3	/* DB checking level for removing entries. */
 
+#ifdef DB_WINDOWS_FORMAT
+#define WINFILEIDLEN  6    /* filename length in windows db e.g. 01to23 */ 
+static const char *StartTag = "#FILENAME="; /* discid tag in "windows" file */
+static const int StartTagLen = 10;     /* length of the tag */
+#endif /* DB_WINDOWS_FORMAT */
+
+#define WINMAXPOSTRECORDS 1000 /* maximum number of records when posting before
+                                  a merge */
 
 /* Structure definitions. */
 
@@ -630,12 +639,13 @@ typedef struct fuzzy_hdr {
 /* Fuzzy table entry data. */
 typedef struct fuzzy_data {
 	unsigned int fd_discid;	/* Disc ID. */
-	int fd_trks;		/* Track count. */
-	short fd_disclen;	/* Length of disc in seconds. */
-	short fd_catind;	/* Category index. */
+	unsigned int fd_trks : 7;		/* Track count. */
+	unsigned int fd_disclen : 13;	/* Length of disc in seconds. */
+	unsigned int fd_catind : 4;	/* Category index. */
 } fdata_t;
 
 
+#define OFFSET_BIT_WIDTH 19
 /* Fuzzy table entry. */
 typedef struct fuzzy_hash {
 	fdata_t fh_s;
@@ -904,7 +914,11 @@ int ck_client_perms(char *, char *, int);
 int crc_email(uint32_t *, FILE *, char *, char *, char *);
 int db_post(db_t *, char *, unsigned int, char *);
 int db_strip(db_t *);
+#ifdef DB_WINDOWS_FORMAT
+int db_write(FILE *fp, db_t *, int level, unsigned int discid);
+#else
 int db_write(FILE *fp, db_t *, int level);
+#endif
 int get_serv_index(char *);
 int fp_copy_buf(FILE *, char *);
 int is_blank(char *, int);
@@ -942,6 +956,7 @@ int parse_utf8(const char **ps);
 
 struct tm *date_to_tm(char *);
 
+char *cddbd_dirname(char *);
 char *cddbd_gets(char *, int);
 char *cddbd_mktemp(void);
 char *cddbd_strcasestr(char *, char *);
@@ -966,7 +981,15 @@ csite_t *getsitenam(char *, int);
 
 lhead_t *fuzzy_search(int, int *, int);
 
+FILE * db_prepare_unix_read(char *, int flags);
+int db_skip2record(FILE *, char *, int);
+int db_skip_separator(FILE *, int);
+
+#ifdef DB_WINDOWS_FORMAT
+db_t *db_read(FILE *, char *, int, int*);
+#else
 db_t *db_read(FILE *, char *, int);
+#endif
 
 clck_t *cddbd_lock_alloc(char *);
 
@@ -978,13 +1001,14 @@ int crc32(int, void *, uint32_t *, uint32_t *);
 
 
 /* External definitions. */
-
+extern unsigned int db_last_read_discid;
 extern int categcnt;
 extern int cgi;
 extern int db_dir_mode;
 extern int db_errno;
 extern int db_file_mode;
 extern int delay_time;
+extern int debug; /* need to export it as well */
 extern int dir_mode;
 extern int dup_ok;
 extern int dup_policy;
@@ -1101,3 +1125,31 @@ int db_utf8_latin1_exact(db_t *db);
 void db_latin1_utf8(db_t *db);
 int db_looks_like_utf8(db_t *db);
 int db_disam_charset(db_t *db);
+
+/* opendir/readdir/closedir for reentrant use (still not threadsafe though) */
+
+/**
+ * One directory entry - used in #dirContext, supports only filename.
+ * 
+ */
+typedef struct dirEntry_
+{
+    char            *d_name; /**< filename - needs to have same name as in dirent */
+    struct dirEntry_ *next;   /**< next entry in the list - internal variable */
+} dirEntry;
+
+/**
+ * Context of a whole directory similar to opendir/readdir_r
+ * 
+ */
+typedef struct
+{
+    char     *dirName;/**< name of the directory */
+    dirEntry *list;   /**< very first item in the list */
+    dirEntry *head;   /**< first unread item */
+    dirEntry *tail;   /**< last inserted item - next insert will be behind */
+} dirContext;
+
+dirContext * winOpenDir(const char *dirName);
+dirEntry * winReadDir(dirContext * context);
+void winCloseDir(dirContext * context);
