@@ -21,8 +21,8 @@
  */
 
 #ifndef LINT
-static char *const _patchlevel_h_ident_ = "@(#)$Id: patchlevel.h,v 1.15 2004/01/10 14:59:23 joerg78 Exp $";
+static char *const _patchlevel_h_ident_ = "@(#)$Id: patchlevel.h,v 1.19.2.1 2004/09/03 15:21:19 joerg78 Exp $";
 #endif
 
-#define VERSION		"1.5"	/* The version number. */
+#define VERSION		"1.5.1"	/* The version number. */
 #define PATCHLEVEL	1		/* The patch level. */
