@@ -21,7 +21,7 @@
  */
 
 #ifndef LINT
-static char *const _sites_c_ident_ = "@(#)$Id: xmit.c,v 1.15 2003/12/02 02:30:51 joerg78 Exp $";
+static char *const _sites_c_ident_ = "@(#)$Id: xmit.c,v 1.18 2004/08/30 18:44:36 joerg78 Exp $";
 #endif
 
 #include <stdlib.h>
@@ -873,7 +873,11 @@ cddbd_do_transmit(csite_t *sp)
 			continue;
 		}
 
+#ifdef DB_WINDOWS_FORMAT
+		db = db_read(fp, errstr, file_df_flags, NULL);
+#else
 		db = db_read(fp, errstr, file_df_flags);
+#endif
 
 		if(db == 0) {
 			switch(db_errno) {
@@ -968,7 +972,11 @@ cddbd_do_transmit(csite_t *sp)
 		    	break;
 			}
 			
+#ifdef DB_WINDOWS_FORMAT
+			if(db_write(tfp, db, use_proto, 0) == 0) {
+#else
 			if(db_write(tfp, db, use_proto) == 0) {
+#endif
 				cddbd_log(LOG_ERR | LOG_XMIT,
 				    "Can't write mail tmp file: %s", tmail);
 				fclose(tfp);
@@ -1260,9 +1268,14 @@ cddbd_put_file(char *site, char *dir, char *file)
 {
 	int ret;
 	FILE *fp;
+#ifdef DB_WINDOWS_FORMAT
+	dirContext *dirp;
+	dirEntry * dp;
+#else
 	DIR *dirp;
-	struct stat sbuf;
 	struct dirent *dp;
+#endif
+	struct stat sbuf;
 	char pfile[CDDBBUFSIZ];
 	char *bfile;
 
@@ -1276,12 +1289,20 @@ cddbd_put_file(char *site, char *dir, char *file)
 	}
 
 	if(S_ISDIR(sbuf.st_mode)) {
+#ifdef DB_WINDOWS_FORMAT
+		if((dirp = winOpenDir(pfile)) == NULL) {
+#else
 		if((dirp = opendir(pfile)) == NULL) {
+#endif
 			cddbd_log(LOG_ERR | LOG_XMIT,
 			    "Can't open directory: %s (%d).", pfile, errno);
 		}
 
+#ifdef DB_WINDOWS_FORMAT
+		while((dp = winReadDir(dirp)) != NULL) {
+#else
 		while((dp = readdir(dirp)) != NULL) {
+#endif
 			if(is_parent_dir(dp->d_name))
 				continue;
 
@@ -1290,7 +1311,11 @@ cddbd_put_file(char *site, char *dir, char *file)
 				break;
 		}
 
+#ifdef DB_WINDOWS_FORMAT
+		winCloseDir(dirp);
+#else
 		closedir(dirp);
+#endif
 
 		ret = 1;
 	}
@@ -1358,10 +1383,15 @@ cddbd_do_catchup(char *site, char *when)
 {
 	int i;
 	time_t t;
+#ifdef DB_WINDOWS_FORMAT
+	dirContext *dirp;
+	dirEntry *dp;
+#else
 	DIR *dirp;
+	struct dirent *dp;
+#endif
 	csite_t *sp;
 	struct stat sbuf;
-	struct dirent *dp;
 	char buf[CDDBBUFSIZ];
 	char cdir[CDDBBUFSIZ];
 	char file[CDDBBUFSIZ];
@@ -1398,10 +1428,18 @@ cddbd_do_catchup(char *site, char *when)
 			cddbd_snprintf(cdir, sizeof(cdir), "%s/%s", cddbdir,
 			    categlist[i]);
 
+#ifdef DB_WINDOWS_FORMAT
+			if((dirp = winOpenDir(cdir)) == NULL)
+#else
 			if((dirp = opendir(cdir)) == NULL)
+#endif
 				continue;
 
+#ifdef DB_WINDOWS_FORMAT
+			while((dp = winReadDir(dirp)) != NULL) {
+#else
 			while((dp = readdir(dirp)) != NULL) {
+#endif
 				cddbd_snprintf(buf, sizeof(buf), "%s/%s", cdir,
 				    dp->d_name);
 
@@ -1437,7 +1475,11 @@ cddbd_do_catchup(char *site, char *when)
 				}
 			}
 
+#ifdef DB_WINDOWS_FORMAT
+			winCloseDir(dirp);
+#else
 			closedir(dirp);
+#endif
 		}
 	}
 
